@@ -10,7 +10,7 @@ use Encode qw(decode_utf8);
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Edge callback.
 sub _edge_callback {
@@ -248,13 +248,17 @@ L<Graph::Reader>.
 
 =head1 SEE ALSO
 
-L<Graph::Reader>,
-L<Graph::Reader::Dot>,
-L<Graph::Reader::HTK>,
-L<Graph::Reader::LoadClassHierarchy>,
-L<Graph::Reader::UnicodeTree>,
-L<Graph::Reader::TGF::CSV>,
-L<Graph::Reader::XML>.
+=over
+
+=item L<Graph::Reader>
+
+base class for Graph file format readers
+
+=item L<Task::Graph::Reader>
+
+Install the Graph::Reader modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -268,10 +272,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2014-2015
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
